---
title: <span class="badge object-type-scalar"></span> Gram
---
# <span class="badge object-type-scalar"></span> Gram

Mass: gram (g)

## Definition

```python
# Mass: gram (g)
Gram: typing.Literal["massg"] = "massg"
```
